﻿/* 
 * Copyright Layne Thomas 2010
 * System color enumeration code from: http://stackoverflow.com/questions/562682/how-can-i-list-colors-with-wpf
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace GradEditWPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        int currentPaletteSize = 3;
        int currentPaletteIndex = 0;

        String[] colorNames = 
        {
            "Red", "Green", "Blue",
            "Black", "White", "Black", "White", "Black", "White", "Black" 
        };

        public MainWindow()
        {
            InitializeComponent();
            SetGradient();
            SetSlider();
        }

        //Set the slider to proper units and index
        private void SetSlider()
        {
            comboBands.SelectedIndex = currentPaletteSize - 1;
            sliderBand.Maximum = currentPaletteSize - 1;
            sliderBand.SmallChange = 1;
        }
        
        //Handler for slider for selected band, updates combo box to proper System.Windows.Media.Color value too
        private void sliderBand_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            currentPaletteIndex = (byte)e.NewValue;
            comboBoxSysColors.Text = "System.Windows.Media.Color "+colorNames[currentPaletteIndex];
            SetSlider();
        }

        //Handler for combo for number of bands
        private void comboBands_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            currentPaletteIndex = 0;
            currentPaletteSize = comboBands.SelectedIndex + 1;
            SetGradient();
            SetSlider();
        }

        //Handler for combo box of system colors
        private void comboBoxSysColors_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            String colorString = comboBoxSysColors.SelectedItem.ToString();
            if (colorString.Length > 0)
            {
                colorNames[currentPaletteIndex] = colorString.Substring(27);
                SetGradient();
                SetSlider();
            }
        }

        //Set the currently displayed gradient to the proper RGB value
        private void SetGradient()
        {
            if (gradrect == null)
                return;
            LinearGradientBrush lgbrush = (LinearGradientBrush)gradrect.Fill;
            GradientStopCollection gscollection = lgbrush.GradientStops;

            GradientStop g;
            gscollection.Clear();
            for (int i = 0; i < currentPaletteSize; i++)
            {
                g = new GradientStop();
                g.Color = (Color)ColorConverter.ConvertFromString(colorNames[i]);
                g.Offset = (float)i / (float)(currentPaletteSize - 1);
                gscollection.Add(g);
            }
            Report();
        }

        //Generate an XML version for WPF to text box
        private void Report()
        {
            String report;
            report = "";

            double offset = 0;
            report = "<LinearGradientBrush StartPoint=\"0,0.5\" EndPoint=\"1,0.5\">\n";
            for (int i = 0; i < currentPaletteSize; i++)
            {
                if (currentPaletteSize > 0)
                    offset = (double)i / (double)(currentPaletteSize - 1);
                else offset = 0;
                report += "\t<GradientStop Color=\"" + colorNames[i] 
                    + "\" Offset=\"" + offset + "\" />\n";
            }
            report += "</LinearGradientBrush>\n";
            if (textBoxGradXML!=null)
                textBoxGradXML.Text = report;
        }
    }
}
